@@ -18,7 +18,6 @@ import os
 import pickle
 import socket
 import stat
-import sys
 
 from psutil import LINUX
 from psutil import POSIX
@@ -27,6 +26,8 @@ from psutil._common import memoize
 from psutil._common import memoize_when_activated
 from psutil._common import supports_ipv6
 from psutil._common import wrap_numbers
+from psutil._common import open_text
+from psutil._common import open_binary
 from psutil._compat import PY3
 from psutil.tests import APPVEYOR
 from psutil.tests import bind_socket
@@ -49,11 +50,13 @@ from psutil.tests import HAS_SENSORS_TEMPERATURES
 from psutil.tests import import_module_by_path
 from psutil.tests import is_namedtuple
 from psutil.tests import mock
+from psutil.tests import PYTHON_EXE
 from psutil.tests import reap_children
 from psutil.tests import reload_module
 from psutil.tests import retry
 from psutil.tests import ROOT_DIR
 from psutil.tests import run_test_module_by_name
+from psutil.tests import safe_mkdir
 from psutil.tests import safe_rmpath
 from psutil.tests import SCRIPTS_DIR
 from psutil.tests import sh
@@ -365,6 +368,8 @@ class TestMisc(unittest.TestCase):
 
     def test_setup_script(self):
         setup_py = os.path.join(ROOT_DIR, 'setup.py')
+        if TRAVIS and not os.path.exists(setup_py):
+            return self.skipTest("can't find setup.py")
         module = import_module_by_path(setup_py)
         self.assertRaises(SystemExit, module.setup)
         self.assertEqual(module.get_version(), psutil.__version__)
@@ -644,19 +649,19 @@ class TestWrapNumbers(unittest.TestCase):
 
 @unittest.skipIf(TOX, "can't test on TOX")
 # See: https://travis-ci.org/giampaolo/psutil/jobs/295224806
-@unittest.skipIf(TRAVIS and not
-                 os.path.exists(os.path.join(SCRIPTS_DIR, 'free.py')),
+@unittest.skipIf(TRAVIS and not os.path.exists(SCRIPTS_DIR),
                  "can't locate scripts directory")
 class TestScripts(unittest.TestCase):
     """Tests for scripts in the "scripts" directory."""
 
     @staticmethod
-    def assert_stdout(exe, args=None, **kwds):
-        exe = '"%s"' % os.path.join(SCRIPTS_DIR, exe)
-        if args:
-            exe = exe + ' ' + args
+    def assert_stdout(exe, *args, **kwargs):
+        exe = '%s' % os.path.join(SCRIPTS_DIR, exe)
+        cmd = [PYTHON_EXE, exe]
+        for arg in args:
+            cmd.append(arg)
         try:
-            out = sh(sys.executable + ' ' + exe, **kwds).strip()
+            out = sh(cmd, **kwargs).strip()
         except RuntimeError as err:
             if 'AccessDenied' in str(err):
                 return str(err)
@@ -704,7 +709,7 @@ class TestScripts(unittest.TestCase):
         self.assert_stdout('meminfo.py')
 
     def test_procinfo(self):
-        self.assert_stdout('procinfo.py', args=str(os.getpid()))
+        self.assert_stdout('procinfo.py', str(os.getpid()))
 
     # can't find users on APPVEYOR or TRAVIS
     @unittest.skipIf(APPVEYOR or TRAVIS and not psutil.users(),
@@ -728,7 +733,7 @@ class TestScripts(unittest.TestCase):
 
     @unittest.skipIf(not HAS_MEMORY_MAPS, "not supported")
     def test_pmap(self):
-        self.assert_stdout('pmap.py', args=str(os.getpid()))
+        self.assert_stdout('pmap.py', str(os.getpid()))
 
     @unittest.skipIf(not HAS_MEMORY_FULL_INFO, "not supported")
     def test_procsmem(self):
@@ -747,7 +752,7 @@ class TestScripts(unittest.TestCase):
         self.assert_syntax('iotop.py')
 
     def test_pidof(self):
-        output = self.assert_stdout('pidof.py', args=psutil.Process().name())
+        output = self.assert_stdout('pidof.py', psutil.Process().name())
         self.assertIn(str(os.getpid()), output)
 
     @unittest.skipIf(not WINDOWS, "WINDOWS only")
@@ -893,6 +898,20 @@ class TestFSTestUtils(unittest.TestCase):
 
     tearDown = setUp
 
+    def test_open_text(self):
+        with open_text(__file__) as f:
+            self.assertEqual(f.mode, 'rt')
+
+    def test_open_binary(self):
+        with open_binary(__file__) as f:
+            self.assertEqual(f.mode, 'rb')
+
+    def test_safe_mkdir(self):
+        safe_mkdir(TESTFN)
+        assert os.path.isdir(TESTFN)
+        safe_mkdir(TESTFN)
+        assert os.path.isdir(TESTFN)
+
     def test_safe_rmpath(self):
         # test file is removed
         open(TESTFN, 'w').close()
@@ -1018,7 +1037,8 @@ class TestNetUtils(unittest.TestCase):
                 # work around http://bugs.python.org/issue30204
                 types[s.getsockopt(socket.SOL_SOCKET, socket.SO_TYPE)] += 1
             self.assertGreaterEqual(fams[socket.AF_INET], 2)
-            self.assertGreaterEqual(fams[socket.AF_INET6], 2)
+            if supports_ipv6():
+                self.assertGreaterEqual(fams[socket.AF_INET6], 2)
             if POSIX and HAS_CONNECTIONS_UNIX:
                 self.assertGreaterEqual(fams[socket.AF_UNIX], 2)
             self.assertGreaterEqual(types[socket.SOCK_STREAM], 2)
