@@ -4,16 +4,17 @@
 # Use of this source code is governed by a BSD-style license that can be
 # found in the LICENSE file.
 
-"""OSX specific tests."""
+"""MACOS specific tests."""
 
 import os
 import re
 import time
 
 import psutil
-from psutil import OSX
+from psutil import MACOS
 from psutil.tests import create_zombie_proc
 from psutil.tests import get_test_subprocess
+from psutil.tests import HAS_BATTERY
 from psutil.tests import MEMORY_TOLERANCE
 from psutil.tests import reap_children
 from psutil.tests import retry_before_failing
@@ -22,7 +23,7 @@ from psutil.tests import sh
 from psutil.tests import unittest
 
 
-PAGESIZE = os.sysconf("SC_PAGE_SIZE") if OSX else None
+PAGESIZE = os.sysconf("SC_PAGE_SIZE") if MACOS else None
 
 
 def sysctl(cmdline):
@@ -75,7 +76,7 @@ def human2bytes(s):
     return int(num * prefix[letter])
 
 
-@unittest.skipIf(not OSX, "OSX only")
+@unittest.skipIf(not MACOS, "MACOS only")
 class TestProcess(unittest.TestCase):
 
     @classmethod
@@ -100,7 +101,7 @@ class TestProcess(unittest.TestCase):
             time.strftime("%Y", time.localtime(start_psutil)))
 
 
-@unittest.skipIf(not OSX, "OSX only")
+@unittest.skipIf(not MACOS, "MACOS only")
 class TestZombieProcessAPIs(unittest.TestCase):
 
     @classmethod
@@ -161,7 +162,7 @@ class TestZombieProcessAPIs(unittest.TestCase):
         self.assertRaises(psutil.ZombieProcess, self.p.memory_maps)
 
 
-@unittest.skipIf(not OSX, "OSX only")
+@unittest.skipIf(not MACOS, "MACOS only")
 class TestSystemAPIs(unittest.TestCase):
 
     # --- disk
@@ -224,12 +225,6 @@ class TestSystemAPIs(unittest.TestCase):
         psutil_val = psutil.virtual_memory().free
         self.assertAlmostEqual(psutil_val, vmstat_val, delta=MEMORY_TOLERANCE)
 
-    @retry_before_failing()
-    def test_vmem_available(self):
-        vmstat_val = vm_stat("inactive") + vm_stat("free")
-        psutil_val = psutil.virtual_memory().available
-        self.assertAlmostEqual(psutil_val, vmstat_val, delta=MEMORY_TOLERANCE)
-
     @retry_before_failing()
     def test_vmem_active(self):
         vmstat_val = vm_stat("active")
@@ -285,6 +280,18 @@ class TestSystemAPIs(unittest.TestCase):
                 self.assertEqual(stats.mtu,
                                  int(re.findall(r'mtu (\d+)', out)[0]))
 
+    # --- sensors_battery
+
+    @unittest.skipIf(not HAS_BATTERY, "no battery")
+    def test_sensors_battery(self):
+        out = sh("pmset -g batt")
+        percent = re.search("(\d+)%", out).group(1)
+        drawing_from = re.search("Now drawing from '([^']+)'", out).group(1)
+        power_plugged = drawing_from == "AC Power"
+        psutil_result = psutil.sensors_battery()
+        self.assertEqual(psutil_result.power_plugged, power_plugged)
+        self.assertEqual(psutil_result.percent, int(percent))
+
 
 if __name__ == '__main__':
     run_test_module_by_name(__file__)
